@@ -222,7 +222,7 @@ QVariant ViewModel::Item::color(int col) const
                 const bt::TrackersStatusInfo tsi = tc->getTrackersList()->getTrackersStatusInfo();
                 if (tsi.trackers_count) {
                     if ((tsi.errors + tsi.warnings) == tsi.trackers_count) {
-                        // no any OK statuses
+                        // no OK statuses
                         if (tsi.timeout_errors)
                             return Settings::timeoutTrackerConnectionColor();
                         if (tsi.warnings)
@@ -283,7 +283,7 @@ QVariant ViewModel::Item::statusIcon() const
     case NO_SPACE_LEFT:
         return QIcon::fromTheme(QStringLiteral("dialog-error"));
     case QUEUED:
-        return QIcon::fromTheme(QStringLiteral("download-later"));
+        return QIcon::fromTheme(tc->getStats().completed ? QStringLiteral("upload-later") : QStringLiteral("download-later"));
     case CHECKING_DATA:
         return QIcon::fromTheme(QStringLiteral("kt-check-data"));
     case PAUSED:
